<?
namespace admin\controls;
class Dashboard
{
  static public function main_view()
  {
    return \Tpl::view( 'dashboard/main-view', [
      'last_orders' => \shop\Dashboard::last_orders(),
      'order_statuses' => \shop\Order::order_statuses(),
      'sales' => \shop\Dashboard::last_24_months_sales(),
      'best_sales_products' => \shop\Dashboard::best_sales_products(),
      'most_view_products' => \shop\Dashboard::most_view_products(),
      'sales_grid' => \shop\Dashboard::sales_grid(),
      'summary_sales' => \shop\Dashboard::summary_sales(),
      'summary_orders' => \shop\Dashboard::summary_orders(),
    ] );
  }
}